# jiaozi

Personal research project, leveraging Jax, numba for 
- faster Statistical hypothesis testing
- using GBDT for works outside of supervised learning, like feature selection, unsupervised learning, Classifier Two-Sample Tests